@@ -37,13 +37,9 @@ operation.  Also provides a hint to the driver.
 
 Cory Watson <gphat@cpan.org>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2010 by Cory G Watson.
 
 You can redistribute and/or modify this code under the same terms as Perl
 itself.
